### 使用方法 ###
# 1. 変数 host に、AWS IoT Core broker の IP アドレスを設定します。例: 'xxx.yyy.zzz.amazonaws.com'
# 2. 変数 cacert に、Root CA ファイルの保存先を設定します。例: '/opt/plcnext/Security/aaa.pem'
# 3. 変数 clientcert に、証明書の保存先を設定します。例: '/opt/plcnext/Security/bbb.pem.crt' 
# 4. 変数 clientKey に、秘密鍵の保存先を設定します。例: '/opt/plcnext/Security/ccc.pem.key'
# 5. 変数 pub_topic に、publish 用トピック名を設定します。例: '/MyPubTopic'
# 6. 変数 message に、送信したいメッセージを設定します。例:  '{"message": "Hello from PLCnext!!"}'  


import paho.mqtt.client as mqtt   # MQTT ライブラリのインポート
import ssl                        # ssl ライブラリのインポート
import time                       # time ライブラリのインポート

host = ''                         # AWS IoT Core broker IP アドレスを指定
port = 8883                       # Broker 接続ポート番号
cacert = ''                       # Root CA ファイルの保存先を指定
clientcert = ''                   # 証明書の保存先を指定
clientKey = ''                    # 秘密鍵の保存先を指定
pub_topic = ''                    # Publish 用トピック名
message = '{"": ""}'              # 送信メッセージ

# ブローカー接続時の処理
def on_connect(client, userdata, flags, rc):
    print("Connected!!")

# ブローカー切断時の処理
def on_disconnect(client, userdata, response_code):
    if response_code != 0:
        print("Disconnected!!")

# メッセージ送信時の処理
def on_publish(client, userdata, mid):
    print("Transmit message:{0}".format(mid))
    
if __name__ == '__main__':
    client = mqtt.Client(protocol=mqtt.MQTTv311)      # MQTT クライアントオブジェクトの作成。 MQTT プロトコル v3.1.1を指定
    
    # TLS 処理
    client.tls_set(cacert,
        certfile = clientcert,
        keyfile = clientKey,
        tls_version = ssl.PROTOCOL_TLSv1_2)
    client.tls_insecure_set(True)

    ### Callback function
    client.on_connect = on_connect         # 接続時のコールバック関数を登録
    client.on_disconnect = on_disconnect   # 切断時のコールバック関数を登録
    client.on_publish = on_publish         # メッセージ送信時のコールバック
    
    client.connect(host, port = port, keepalive = 60) # Broker と接続
    time.sleep(10)

    client.loop_start()   # 通信開始

    while True:
        client.publish(pub_topic, message)      # メッセージ送信
        time.sleep(10)                          # 10秒間待つ
